==> gchempaint-0.7.5.tar.gz: gchempaint-0.7.5/lib/settings.h <==
// -*- C++ -*-

/* 
 * GChemPaint libray
 * settings.h 
 *
 * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GCHEMPAINT_SETTINGS_H
#define GCHEMPAINT_SETTINGS_H

#include <glib.h>
#include <pango/pango.h>

/*
extern double DefaultBondLength;
extern double DefaultBondAngle;
extern double DefaultBondDist;
extern double DefaultBondWidth;
extern double DefaultArrowLength;
extern double DefaultHashWidth;
extern double DefaultHashDist;
extern double DefaultStereoBondWidth;
extern double DefaultZoomFactor;
extern double DefaultPadding;
extern double DefaultArrowHeadA;
extern double DefaultArrowHeadB;
extern double DefaultArrowHeadC;
extern double DefaultArrowDist;
extern double DefaultArrowPadding;
extern double DefaultStoichiometryPadding;
extern double DefaultObjectPadding;
extern double DefaultSignPadding;
extern double DefaultChargeSignHeight;
extern double DefaultChargeSignSize;
extern double DefaultChargeYAlign;*/
extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
/*extern gchar *DefaultFontFamily, *DefaultTextFontFamily;
extern PangoStyle DefaultFontStyle;
extern PangoWeight DefaultFontWeight;
extern PangoVariant DefaultFontVariant;
extern PangoStretch DefaultFontStretch;
extern gint DefaultFontSize;*/
extern unsigned MaxStackSize;
extern bool MergeAtoms;

#endif // GCHEMPAINT_SETTINGS_H

==> gchempaint_0.8.7.orig.tar.gz: gchempaint-0.8.7/lib/settings.h <==
// -*- C++ -*-

/* 
 * GChemPaint libray
 * settings.h 
 *
 * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GCHEMPAINT_SETTINGS_H
#define GCHEMPAINT_SETTINGS_H

#include <glib.h>
#include <pango/pango.h>

#define ROOTDIR "/apps/gchempaint/settings/"

extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
extern unsigned MaxStackSize;
extern bool MergeAtoms;
extern int CompressionLevel;
extern bool TearableMendeleiev;

// Clipboard formats identifiers
enum {
	GCP_CLIPBOARD_NATIVE,
	GCP_CLIPBOARD_SVG,
	GCP_CLIPBOARD_SVG_XML,
	GCP_CLIPBOARD_PNG,
	GCP_CLIPBOARD_JPEG,
	GCP_CLIPBOARD_BMP,
	GCP_CLIPBOARD_NO_TEXT,
	GCP_CLIPBOARD_UTF8_STRING = GCP_CLIPBOARD_NO_TEXT,
	GCP_CLIPBOARD_STRING,
	GCP_CLIPBOARD_ALL,
};

extern int ClipboardFormats; /* number of really used formats when copying
should be either GCP_CLIPBOARD_NO_TEXT or GCP_CLIPBOARD_ALL */

#endif // GCHEMPAINT_SETTINGS_H
